@@ -44,8 +44,8 @@ GIT_ABBREV_LENGTH = 12
 # If the text "$Format" is still present, it means that
 # git archive did not replace the $Format string, which
 # means that this not a git archive.
-GIT_EXPORT_SUBST_H = 'c552f74cdc235956749afb80f6536ca8c9c145d7'
-GIT_EXPORT_SUBST_D = 'tag: wireshark-4.0.3, tag: v4.0.3, refs/merge-requests/9517/head, refs/keep-around/c552f74cdc235956749afb80f6536ca8c9c145d7'
+GIT_EXPORT_SUBST_H = 'e556162d8da3dc05397bd16a57caa042e62f8e9e'
+GIT_EXPORT_SUBST_D = 'tag: wireshark-4.0.5, tag: v4.0.5, refs/merge-requests/10294/head, refs/keep-around/e556162d8da3dc05397bd16a57caa042e62f8e9e'
 IS_GIT_ARCHIVE = not GIT_EXPORT_SUBST_H.startswith('$Format')
 
 
@@ -123,8 +123,8 @@ def update_attributes_asciidoc(src_dir, repo_data):
 
 def update_docinfo_asciidoc(src_dir, repo_data):
     doc_paths = []
-    doc_paths += [os.path.join(src_dir, 'docbook', 'developer-guide-docinfo.xml')]
-    doc_paths += [os.path.join(src_dir, 'docbook', 'user-guide-docinfo.xml')]
+    doc_paths += [os.path.join(src_dir, 'docbook', 'wsdg_src', 'developer-guide-docinfo.xml')]
+    doc_paths += [os.path.join(src_dir, 'docbook', 'wsug_src', 'user-guide-docinfo.xml')]
 
     for doc_path in doc_paths:
         with open(doc_path, encoding='utf-8') as fh:
